@@ -6,7 +6,17 @@ use Carp;
 use File::ShareDir ':ALL';
 use Path::Tiny;
 
-our $VERSION = '0.011';
+our $VERSION = '0.012';
+
+has admin_menu => sub {
+  my $self = shift;
+  return +{};
+};
+
+has frontend_menu => sub {
+  my $self = shift;
+  return +{};
+};
 
 sub startup {
     my $self = shift;
@@ -30,23 +40,28 @@ sub startup {
 ###############################################################################
 # Load global plugins
 ###############################################################################
+    push @{$self->plugins->namespaces}, 'App::skryf::Plugin';
     for (keys $cfg->{extra_modules}) {
         $self->plugin("$_") if $cfg->{extra_modules}{$_} > 0;
     }
 
 ###############################################################################
-# Load local plugins
+# Load Core plugins
 ###############################################################################
-    push @{$self->plugins->namespaces}, 'App::skryf::Plugin';
-    $self->plugin('Blog' => {authentication => $self->session('user')});
-    $self->plugin('Wiki' => {authentication => $self->session('user')});
+    $self->plugin(
+        'Search' => {
+            tapir_token  => $cfg->{social}{tapir},
+            tapir_secret => $cfg->{social}{tapir_secret}
+        }
+    );
 
 ###############################################################################
 # Define template, media, static paths
 ###############################################################################
     my $template_directory = undef;
     my $media_directory    = undef;
-    if ($self->mode eq "development" || !defined($cfg->{template_directory})) {
+    if ($self->mode eq "development" || !defined($cfg->{template_directory}))
+    {
         $template_directory = path(dist_dir('App-skryf'), 'templates');
         $media_directory    = path(dist_dir('App-skryf'), 'public');
     }
@@ -72,39 +87,29 @@ sub startup {
     my $r = $self->routes;
 
     # Authentication
+    # TODO: make pluggable
     $r->get('/login')->to('login#login')->name('login');
     $r->get('/logout')->to('login#logout')->name('logout');
     $r->post('/auth')->to('login#auth')->name('auth');
-  }
+
+    # TODO: make splashpage overridable
+    $r->get('/')->to(
+        namespace => 'App::skryf::Plugin::Blog::Controller',
+        action    => 'blog_splash'
+    )->name('splashpage');
+}
 1;
 
 __END__
 
 =head1 NAME
 
-App-skryf - i kno rite. another perl blogging engine.
+App-skryf - i kno rite. another perl cms.
 
 =head1 DESCRIPTION
 
-Another blog engine which utilizes
-
-=over 8
-
-=item Mojolicious
-
-=item Markdown
-
-=item Hypnotoad
-
-=item Rex
-
-=item Ubic 
-
-=item Mongo
-
-=back
-
-For a more streamlined deployable approach.
+Another CMS platform which utilizes Mojolicious, Markdown, hypnotoad, Rex, Ubic,
+and Mongo.
 
 =head1 PREREQS
 
@@ -120,17 +125,17 @@ I like L<http://perlbrew.pl>, but, whatever you're comfortable with. I won't jud
 
 By default B<skryf> will look in dist_dir for templates and media. To override that
 make sure I<~/.skryf.conf> points to the locations of your templates and media.
-For example, this is a simple directory structure for managing your blog media and templates.
+For example: 
 
     $ mkdir -p ~/blog/{templates,public}
 
-Edit ~/.skryf.conf to reflect those directories in I<media_directory> and 
-I<public_directory>.
+Edit ~/.skryf.conf to reflect those directories in I<template_directory> and 
+I<media_directory>.
 
     template_directory => '~/blog/templates',
     media_directory    => '~/blog/public',
 
-So B<~/blog/templates/{post.html.ep,index.html.ep,about.html.ep}> and B<~/blog/public/style.css>
+So B<~/blog/templates/blog/detail.html.ep> and B<~/blog/public/style.css>
 
 =head1 DEPLOY
 
