@@ -6,12 +6,17 @@ use warnings;
 use Method::Signatures;
 use Text::MultiMarkdown 'markdown';
 use String::Dirify 'dirify';
+use String::Util 'trim';
 use XML::Atom::SimpleFeed;
 use Encode;
 use DateTime::Format::RFC3339;
 
-method convert ($content) {
-    markdown($content);
+method convert ($content, $use_wikilinks=0) {
+    markdown($content, {
+    empty_element_suffix => '>',
+    tab_width => 2,
+    use_wikilinks => $use_wikilinks,
+  });
 }
 
 method slugify ($topic, $auto = 0) {
